<?php

/**
 * Skeleton subclass for representing a row from the 'igaleria_tbl' table.
 *
 *
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    lib.model
 */
class GaleriaI extends BaseGaleriaI {
    protected $aGiObraz;
    protected $collGiObrazs;
    protected $lastGiObrazCriteria;

    public function __toString() {
        $culture = sfContext::getInstance()->getUser()->getCulture();
        if (!$culture) {
            $culture = sfConfig::get('app_db_default_language'); //'pl';
        }
        return $this->getTytul($culture);
    }

    public function getSubs(Criteria $crit = null) {
        if (!$crit)
            $crit = new Criteria();

        $all = GaleriaIPeer::getInstance()->getAllSubs($crit);
        $subs = array();
        foreach ($all as $sub) {
            if ($sub->getGaleriaId() == $this->getPrimaryKey()) {
                $subs[] = $sub;
            }
        }
        return $subs;
    }

    public function countSubs() {
        $all = GaleriaIPeer::getInstance()->getAllSubs();
        $subs = 0;
        foreach ($all as $sub) {
            if ($sub->getGaleriaId() == $this->getPrimaryKey()) {
                $subs++;
            }
        }
        return $subs;
    }

    public function moveDown() {
        $ctest = new Criteria();
        $ctest->addDescendingOrderByColumn(GaleriaIPeer::KOLEJNOSC);
        $ctest->add(GaleriaIPeer::SUBKATEGORIA_ID, $this->getSubkategoriaId());
        $ctest->clearSelectColumns();
        $ctest->addSelectColumn(GaleriaIPeer::KOLEJNOSC);

        $dist = GaleriaIPeer::doCount($ctest, true);
        $all = GaleriaIPeer::doCount($ctest, false);

        if ($dist < $all) {
            GaleriaPeer::sortSub($this->getSubkategoriaId());
            $this->reload();
        }

        $cup = new Criteria();
        $cup->addAscendingOrderByColumn(GaleriaIPeer::KOLEJNOSC);
        $cup->add(GaleriaIPeer::SUBKATEGORIA_ID, $this->getSubkategoriaId());
        $cup->add(GaleriaIPeer::KOLEJNOSC, $this->getKolejnosc(), Criteria::GREATER_THAN);
        $up = GaleriaIPeer::doSelectOne($cup);

        if ($up) {
            $upd = $up->getKolejnosc();
        } else {
            $upd = 'NONE';
        }
        if ($up) {
            $temp = $this->getKolejnosc();
            $this->setKolejnosc($up->getKolejnosc());
            $up->setKolejnosc($temp);
            $up->save();
            $upd = $up->getKolejnosc();
        } else {
            $this->setKolejnosc(($this->getKolejnosc()) + 1);
        }
        $this->save();
    }

    public function moveUp() {
        $ctest = new Criteria();
        $ctest->addDescendingOrderByColumn(GaleriaIPeer::KOLEJNOSC);
        $ctest->add(GaleriaIPeer::SUBKATEGORIA_ID, $this->getSubkategoriaId());
        $ctest->clearSelectColumns();
        $ctest->addSelectColumn(GaleriaIPeer::KOLEJNOSC);

        $dist = GaleriaIPeer::doCount($ctest, true);
        $all = GaleriaIPeer::doCount($ctest, false);

        if ($dist < $all) {
            GaleriaPeer::sortSub($this->getSubkategoriaId());
            $this->reload();
        }

        $cup = new Criteria();
        $cup->addDescendingOrderByColumn(GaleriaIPeer::KOLEJNOSC);
        $cup->add(GaleriaIPeer::SUBKATEGORIA_ID, $this->getSubkategoriaId());
        $cup->add(GaleriaIPeer::KOLEJNOSC, $this->getKolejnosc(), Criteria::LESS_THAN);
        $up = GaleriaIPeer::doSelectOne($cup);

        if ($up) {
            $upd = $up->getKolejnosc();
        } else {
            $upd = 'NONE';
        }
        if ($up) {
            $temp = $this->getKolejnosc();
            $this->setKolejnosc($up->getKolejnosc());
            $up->setKolejnosc($temp);
            $up->save();
            $upd = $up->getKolejnosc();
        } else {
            $this->setKolejnosc(($this->getKolejnosc()) - 1);
        }
        $this->save();
    }

    public function save(PropelPDO $con = null) {
        if ($this->isModified() && $this->isColumnModified(GaleriaIPeer::SUBKATEGORIA_ID)) {
            $cup = new Criteria();
            $cup->addAscendingOrderByColumn(GaleriaIPeer::KOLEJNOSC);
            $cup->add(GaleriaIPeer::SUBKATEGORIA_ID, $this->getSubkategoriaId());
            $up = GaleriaIPeer::doSelectOne($cup);

            if ($up) {
                $this->setKolejnosc($up->getKolejnosc() + 1);
            } else {
                $this->setKolejnosc(0);
            }
        }
        parent::save($con);
    }

    public function publish() {
        $data = $this->toArray(BasePeer::TYPE_FIELDNAME);
        $main = GaleriaIPubPeer::retrieveByPK($this->getId());
        if (!$main)
            $main = new GaleriaIPub();

        $main->fromArray($data, BasePeer::TYPE_FIELDNAME);
        $main->clearGaleriaIPubI18ns();

        //Jezeli tego nie zrobimy to relacja bedzie Invalid
        $zaj = $this->getObrazId();
        if ($zaj) {
            unset($data['obraz_id']);
            $main->setObrazId(null);
        }

        foreach ($this->getGaleriaII18ns() as $i18n) {
            $i18n_data = $i18n->toArray(BasePeer::TYPE_FIELDNAME);
            unset($i18n_data['id'], $i18n_data['culture']);
            $data[$i18n->getCulture()] = $i18n_data;
        }

        $pubform = new GaleriaIPubForm($main);
        //FIXME: Dlaczego to jest ustawione na zero tak swoja droga?
        $data['widoczna'] = 1;

        $pubform->bind($data);

        $publish = array();
        $publish[0] = $pubform;

        if ($pubform->isValid()) {
            // Publikujemy

            try {
                $pubform->save();
                $main = $pubform->getObject();

                //Publikacja obrazków
                $publish[0] = $pubform;

                $ods = array();
                foreach ($this->getGiObrazs() as $obraz) {
                    $opub = $obraz->publish();
                    //$publish[] = $opub;
                    $oids[] = $opub->getObject()->getId();
                }

                //Teraz mamy obrazki (miejmy nadzieję)
                if ($zaj) {
                    $main->setObrazId($zaj);
                    $data['obraz_id'] = $zaj;
                    $pubform = new GaleriaIPubForm($main);
                    $pubform->bind($data);
                    $pubform->save();
                    $publish[0] = $pubform;
                }
            } catch (PropelException $e) {
                throw $e;
            }

            //Dopisujemy rekord do statystyk.rankingu
            $pubed = $pubform->getObject();
            $rank = $pubed->getGiRank();
            if (!$rank) {
                $rank = new GiRank();
                $rank->setGaleriaId($pubed->getId());
            }
            $rank->save();
            $this->setWidoczna(1);
            try {
                $this->save();
            } catch (PropelException $e) {
                $this->getUser()->setFlash('error', $e->getMessage());
            }
        }
        
        // powiadomienie dispatchera
        $t2 = microtime(true);
        $dispatcher = sfContext::getInstance()->getEventDispatcher();
        $dispatcher->notify(new sfEvent($this, 'gali.publish', array('module_short' => 'gali', 'obj_id' => $this->getId())));
        $t3 = microtime(true);


        // Zwracamy formularz Publikacji (z ewentualnymi błędami)
        return $publish;
    }

    public function unpublish() {
        $published = GaleriaIPubPeer::retrieveByPK($this->getId());

        if ($published) {
            try {
                $published->delete();
            } catch (PropelException $e) {
                throw $e;
            }
        }
    }

    public function delete(PropelPDO $con = null) {
        $id = $this->getId();

        if ($this->isDeleted()) {
            throw new PropelException("This object has already been deleted.");
        }

        //Odpinamy obrazek zajawiki by uniknąć kołowej relacji (genialne!)
        $this->setObrazId(null);
        $this->save();

        $this->unpublish();

        foreach ($this->getGiObrazs() as $obraz) {
            $obraz->delete();
        }

        $dirname = sfConfig::get('sf_upload_dir') . "/temp/gali/gal_" . $this->getId();
        if ($con === null) {
            $con = Propel::getConnection(GaleriaIPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
        }

        $con->beginTransaction();
        try {
            GaleriaIPeer::doDelete($this, $con);
            $this->setDeleted(true);
            $con->commit();
        } catch (PropelException $e) {
            $con->rollBack();
            //throw $e;
        }

        //Usuwamy katalog i pliki
        if (is_dir($dirname))
            exec("rm -rf " . $dirname);
    }

    public function checkPermission(sfUser $user=null, $val=null) {
        if (!$user)
            $user = sfContext::getInstance()->getUser();
        if (!sfGuardPermission::validPerm($val))
            return false;

        $perm = "gali_gal_{$this->getPrimaryKey()}";
        $permission = $user->checkPermission($perm, $val);

        switch ($permission) {
            case 1:
                return true;
            case -1:
                return false;
            case 0;
                $parent = $this->getGiSubkategoria();
                $par = $parent->checkPermission($user, $val);
                switch ($par) {
                    case 1:
                        return true;
                    case -1;
                        return false;
                    default:
                        $usr = $user->checkPermission('gali_user', $val);
                        if (($this->getUzytkownikId() == $user->getId()) && ($usr == 1)) {
                            return true;
                        }
                        $global = $user->checkPermission('gali_global', $val);
                        if ($global == 1) {
                            return true;
                        }
                }
            default:
                return false;
        }
    }

    public function isPublished() {
        $crit = new Criteria();
        $crit->add(GaleriaIPubPeer::ID, $this->getId());
        $pubs = GaleriaIPubPeer::doCount($crit);
        return $pubs ? true : false;
    }

    public function getGiObraz(PropelPDO $con = null) {
        if ($this->aGiObraz === null && ($this->obraz_id !== null)) {
            $c = new Criteria(GiObrazPeer::DATABASE_NAME);
            $c->add(GiObrazPeer::ID, $this->obraz_id);
            $this->aGiObraz = GiObrazPeer::doSelectOne($c, $con);
        }
        return $this->aGiObraz;
    }

    public function getGiObrazs($criteria = null, PropelPDO $con = null) {
        if ($criteria === null) {
            $criteria = new Criteria(GaleriaIPeer::DATABASE_NAME);
        } elseif ($criteria instanceof Criteria) {
            $criteria = clone $criteria;
        }

        if ($this->collGiObrazs === null) {
            if ($this->isNew()) {
                $this->collGiObrazs = array();
            } else {

                $criteria->add(GiObrazPeer::GALERIA_ID, $this->id);

                GiObrazPeer::addSelectColumns($criteria);
                $this->collGiObrazs = GiObrazPeer::doSelect($criteria, $con);
            }
        } else {
            if (!$this->isNew()) {


                $criteria->add(GiObrazPeer::GALERIA_ID, $this->id);

                GiObrazPeer::addSelectColumns($criteria);
                if (!isset($this->lastGiObrazCriteria) || !$this->lastGiObrazCriteria->equals($criteria)) {
                    $this->collGiObrazs = GiObrazPeer::doSelect($criteria, $con);
                }
            }
        }
        $this->lastGiObrazCriteria = $criteria;
        return $this->collGiObrazs;
    }

}
