<?php

/**
 * Skeleton subclass for representing a row from the 'igaleria_pub' table.
 *
 *
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    lib.model
 */
class GaleriaIPub extends BaseGaleriaIPub {

    protected $aGiObrazPub;
    protected $collGiObrazPubs;
    protected $lastGiObrazPubCriteria;

    public function __toString() {
        return $this->getTytul(sfContext::getInstance()->getUser()->getCulture());
    }

    /**
     * Zwiększa parametr views obiektu o parametr $do
     *
     * @param int $do = 1
     * @return unknown
     */
    public function increaseViews($do = 1) {
        if ($this->isNew()) {
            return false;
        }
        $rank = $this->getGiRank();
        if (!$rank) {
            $rank = new GiRank();
            $rank->setPrimaryKey($this->getPrimaryKey());
            $rank->setViews($do);
        } else {
            //Sprawdzamy czy nie trzeba dopisać nowych statystyk
            $year = (int) substr($rank->getUpdatedAt(), 0, 4);
            $month = (int) substr($rank->getUpdatedAt(), 5, 7);
            $update = mktime(0, 0, 0, $month + 1, 1, $year);
            if ($update < time()) {
                $stat = new GiStat();
                $stat->setPrimaryKey(array($this->getPrimaryKey(), $year, $month));
                $stat->setWejsc($rank->getViews());
                $stat->save();
                $rank->setViews($do);
            }
            $rank->setViews($rank->getViews() + $do);
        }
        $rank->save();
        return true;
    }

    public function hasStats() {
        $rank = $this->getGiRank();
        if ($rank) {
            /*
             * Sprawdzamy kiedy obiekt powstał,
             * jeżeli w tym miesiącu to nie ma sensu wykonywać zapytania do bazy.
             */
            $year = (int) substr($rank->getCreatedAt(), 0, 4);
            $month = (int) substr($rank->getCreatedAt(), 5, 7);
            $created = mktime(0, 0, 0, $month + 1, 1, $year);
            if ($created < time()) {
                return $this->countGiStats();
            }
        } else {
            return 0;
        }
    }

    public function getViews() {
        $rank = $this->getGiRank();
        if ($rank) {
            return $rank->getViews();
        } else {
            return 0;
        }
    }

    public function getAllViews() {
        $views = 0;
        foreach ($this->getGiStats() as $stat) {
            $views += $stat->getWejsc();
        }
        $rank = $this->getGiRank();
        if ($rank) {
            $views += $rank->getViews();
        }
        return $views;
    }

    public function getLastViewed() {
        $rank = $this->getGiRank();
        if ($rank) {
            return $rank->getUpdatedAt();
        } else {
            return 'Nieznane';
        }
    }

    public function getRank() {
        $rank = $this->getGiRank();
        if ($rank) {
            return array('rank' => $rank->getRank(), 'voters' => $rank->getVoters());
        } else {
            return array('rank' => 0, 'voters' => 0);
        }
    }

    public function addVote($val) {
        $rec = $this->getGiRank();
        if (!$rec) {
            $rec = new GiRank();
            $rec->setGaleriaId($this->getPrimaryKey());
        }
        $rank = $rec->getRank();
        $voters = $rec->getVoters();
        // Średnia ważona
        $rank = (($rank * $voters) + ($val)) / ($voters + 1);
        $rec->setVoters($voters + 1);
        $rec->setRank($rank);
        $rec->save();
    }

    public function getZajawka($culture = null) {
        sfContext::getInstance()->getConfiguration()->loadHelpers('Funkcje');
        return(replaceEmail(parent::getZajawka($culture), true));
    }

    public function countSubs() {
        $all = $this->getGiObrazPubs();
        $subs = count($all);
        return $subs;
    }

    public function delete(PropelPDO $con = null) {
        $id = $this->getId();

        if ($this->isDeleted()) {
            throw new PropelException("This object has already been deleted.");
        }

        //Usuwamy kołową zależność blokującą usuwanie
        $this->setObrazId(null);
        $this->save();

        foreach ($this->getGiObrazPubs() as $obraz) {
            $obraz->delete();
        }

        $dirname = sfConfig::get('sf_upload_dir') . "/pub/galp/gal_" . $this->getId();
        if ($con === null) {
            $con = Propel::getConnection(GaleriaIPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
        }

        $con->beginTransaction();
        try {
            GaleriaIPubPeer::doDelete($this, $con);
            $this->setDeleted(true);
            $con->commit();
        } catch (PropelException $e) {
            $con->rollBack();
            throw $e;
        }

        //Usuwamy katalog i pliki
        if (is_dir($dirname)) {
            Functions::rrmdir($dirname);
        }
    }

    public function save(PropelPDO $con = null) {
        if ($this->isModified() && !$this->isColumnModified(GaleriaIPubPeer::UPDATED_AT)) {
            $this->setUpdatedAt(time());
        }

        if ($this->isNew() && !$this->isColumnModified(GaleriaIPubPeer::CREATED_AT)) {
            $this->setCreatedAt(time());
        }

        if ($this->isDeleted()) {
            throw new PropelException("You cannot save an object that has been deleted.");
        }

        if ($con === null) {
            $con = Propel::getConnection(GaleriaIPubPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
        }

        $con->beginTransaction();
        try {
            $affectedRows = $this->doSave($con);
            $con->commit();
            $this->addGiRank();
            GaleriaIPubPeer::addInstanceToPool($this);
            return $affectedRows;
        } catch (PropelException $e) {
            $con->rollBack();
            throw $e;
        }
    }

    public function addGiRank() {
        $rec = $this->getGiRank();
        if (!$rec) {
            $rec = new GiRank();
            $rec->setGaleriaId($this->getPrimaryKey());
        }
    }

    public function checkPermission(sfUser $user, $val) {
        if (!$val || !sfGuardPermission::validPerm($val))
            return false;

        $perm = "gali_global";
        if ($user->checkPermission($perm, $val))
            return true;

        if ($user->getId() == $this->getUzytkownikId()) {
            if ($val == 'edit')
                return true;

            $perm = "gali_user";
            if ($user->checkPermission($perm, $val))
                return true;
        }

        $perm = "gali_gal_{$this->getPrimaryKey()}";
        $permission = $user->checkPermission($perm, $val);

        switch ($permission) {
            case 1:
                return true;
            case -1:
                return false;
            case 0;
                $parent = $this->getGiSubkategoria();
                if ($parent && $parent->checkPermission($user, $val)) {
                    return true;
                }
            default:
                return false;
        }
    }

    public function getGiObrazPub(PropelPDO $con = null) {
        if ($this->aGiObrazPub === null && ($this->obraz_id !== null)) {
            $c = new Criteria(GiObrazPubPeer::DATABASE_NAME);
            $c->add(GiObrazPubPeer::ID, $this->obraz_id);
            $this->aGiObrazPub = GiObrazPubPeer::doSelectOne($c, $con);
        }
        return $this->aGiObrazPub;
    }
}
