<?php

/**
 * Skeleton subclass for performing query and update operations on the 'igaleria_pub' table.
 *
 *
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    lib.model
 */
class GaleriaIPubPeer extends BaseGaleriaIPubPeer {

    private $allSubs = null;
    private $crit = null;
    static $instance;

    public static function getInstance() {
        if (!self::$instance) {
            return self::$instance = new self();
        }
        return self::$instance;
    }

    public function getAllSubs(Criteria $crit = null) {
        if (!$crit) {
            $crit = new Criteria();
        }
        
        if (!$this->allSubs || (!$crit->equals($this->crit))) {
            $this->crit = $crit;
            $this->allSubs = GiObrazPeer::doSelect($crit);
        }
        return $this->allSubs;
    }

    public static function getUserGallery() {
        $c = new Criteria();
        $c->add(GaleriaIPubPeer::UZYTKOWNIK_ID, sfContext::getInstance()->getUser()->getId());
        $c->addAscendingOrderByColumn(GaleriaIPubI18nPeer::TYTUL);

        //$c->addJoin(AGaleriaPubPeer::GALERIA_ID, GaleriaPubPeer::ID);

        return GaleriaIPubPeer::doSelect($c);
    }

    public static function getAllGallery() {
        $c = new Criteria();
        //$c->add(GaleriaPubPeer::UZYTKOWNIK_ID, sfContext::getInstance()->getUser()->getId());
        $c->addAscendingOrderByColumn(GaleriaIPubI18nPeer::TYTUL);

        //$c->addJoin(AGaleriaPubPeer::GALERIA_ID, GaleriaPubPeer::ID);

        return GaleriaIPubPeer::doSelect($c);
    }

    public static function buildCurrentCriteria() {
        $crit = GiKategoriaPeer::buildBasicCriteria();
        $crit->addJoin(GiKategoriaPeer::ID, GiSubkategoriaPeer::KATEGORIA_ID);
        $crit->addJoin(GiSubkategoriaPeer::ID, GaleriaIPubPeer::SUBKATEGORIA_ID);
        //$crit->add(GaleriaPubPeer::WIDOCZNA,1);
        return $crit;
    }
    
    /**
     * metoda pobierajaca pozostale galerie z kategorii, do ktorej nalezy
     * galeria o podanym id
     * @author      Tomasz Glowinski, 2012
     * @param       Integer $gal_id id galerii
     * @param       Integer $perpage [opcjonalne] ilosc pozycji na stronie pagera
     * @return      obiekt typu pager z lista pozostalych galerii w kategorii
     *              lub null w przypadku bledu
     */
    public static function getCategoryRestGalleriesByGalleryId($gal_id, $perpage = null)
    {
        try
        {
            if (empty($gal_id) || !is_numeric($gal_id))
                throw new Exception('Brak lub niepoprawny parametr');

            if (empty($perpage) || !is_numeric($perpage))
                $perpage = sfConfig::get('app_pages');

            // pobieram obiekt galerii z bazy
            $gal = GaleriaIPubPeer::retrieveByPK($gal_id);
            if (empty($gal))
                throw new Exception('Nie ma takiej galerii');

            // wydobywam kategorie, do ktorej nalezy podana galeria
            $gal_cat_id = $gal->getGiSubkategoria()->getKategoriaId();
            if (empty($gal_cat_id))
                throw new Exception('Nie ma takiej kategorii');

            // kryteria wyboru galerii
            $c = self::buildCurrentCriteria();
            $c->add(GiSubkategoriaPeer::KATEGORIA_ID, $gal_cat_id);
            $c->add(GaleriaIPubPeer::ID, $gal_id, Criteria::NOT_EQUAL);
            $c->addDescendingOrderByColumn(GaleriaIPubPeer::CREATED_AT);
            
            // pager
            $pager = new sfPropelPager('GaleriaIPub', $perpage);
            $pager->setPeerMethod('doSelectWithI18n');
            $pager->setCriteria($c);

            return $pager;
        }
        catch (Exception $e)
        {
            if ($_SERVER['SCRIPT_NAME'] == '/index_dev.php')
                print_r('<pre>'.'GaleriaIPubPeer: '.$e->getMessage().'</pre>');

            return null;
        }
    }

}
