<?php

/**
 * Skeleton subclass for performing query and update operations on the 'igaleria_kategoria_tbl' table.
 *
 *
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    lib.model
 */
class GiKategoriaPeer extends BaseGiKategoriaPeer
{
    private $allSubs = null;
    static $instance;

    public static function getInstance()
    {
        if(!self::$instance)
        {
            return self::$instance = new self();
        }
        return self::$instance;
    }

    public function getAllSubs($crit = null)
    {
        if(!$crit)
            $crit = new Criteria();
        if(count($this->allSubs))
        {
            foreach($this->allSubs as $sub)
            {
                if($crit->equals($sub['crit']))
                {
                    return $sub['list'];
                }
            }
        }
        $list = GiSubkategoriaPeer::doSelect($crit);
        $this->allSubs[] = array('crit' => $crit, 'list' => $list);
        return $list;
    }

    public static function buildBasicCriteria(Criteria $crit = null)
    {
        if(!$crit)
            $crit = new Criteria();
        
        if(sfConfig::get('multisite'))
        {
            $crit->add(GiKategoriaPeer::ID, sfConfig::get('portal')->getCat('gali'));
        }
        else
        {
            /* Usunięte w zwiazku ze skargami na zniknięcia
              $other = sfConfig::get('portal')->getOtherCats('gali');
              foreach ($other as $cat) {
              $crit->addAnd(GiKategoriaPeer::ID,$cat,Criteria::NOT_EQUAL);
              }
             */
        }
        return $crit;
    }

    public static function getAvailableTopLevel()
    {
        $c = self::buildBasicCriteria();
        $c->add(self::WIDOCZNA, 0);
        $c->addAscendingOrderByColumn(self::KOLEJNOSC);

        return self::doSelectJoinAllWithI18n($c);
    }

    /**
     * Metoda zwracajaca liste wszystkich dostepnych kategorii. W przypadku, gdy 
     * pewna kategoria jest dostepna a jej rodzic nie - zwracana jest wylacznie podkategoria.
     * Ustawienie flagi <code>$with_parents</code> powoduje zwrocenie rowniez rodzicow.
     * @return      array lista agregowanych kategorii - dostepnych na biezacym portalu spoza niego
     * @author      Tomasz Glowinski, 2017
     */
    public static function getAvailable()
    {
        $ret = array();
        
        $top_levels = self::getAvailableTopLevel();
        foreach($top_levels as $top_level)
        {
            $ret[$top_level->getId()] = array('obj' => $top_level, 'sub' => array());
        }
        
        $subs_c = GiSubkategoriaPeer::buildBasicCriteria();
        $subs_c->addAscendingOrderByColumn(GiSubkategoriaPeer::KOLEJNOSC);
        $sub_levels = GiSubkategoriaPeer::doSelectJoinAllWithI18n($subs_c);
        
        foreach($sub_levels as $sub_level)
        {
            $ret[$sub_level->getKategoriaId()]['sub'][$sub_level->getId()] = array('obj' => $sub_level, 'sub' => array());
        }

        // zwrocenie wyniku
        return $ret;
    }

}